@@ -58,7 +58,9 @@ my $do_version     = 0;
 my @limit_hosts    = ();
 my @limit_services = ();
 my @limit_contacts = ();
+my @always_send    = ();
 my $stdout         = 0;
+my $force          = 0;
 my $force_run_as_root = 0;
 my %notes          = ();
 my $config;
@@ -86,6 +88,8 @@ sub limits_startup {
         "config=s"  => \$conffile,
         "debug!"    => \$DEBUG,
         "stdout!"   => \$stdout,
+        "force!"    => \$force,
+        "always-send=s" => \@always_send,
         "force-run-as-root!" => \$force_run_as_root,
         "version!"  => \$do_version,
         "help"      => \$do_usage
@@ -96,6 +100,8 @@ sub limits_startup {
 
     exit_if_run_by_super_user() unless $force_run_as_root;
 
+    @always_send = qw{ok warning critical unknown} if $force;
+
     munin_readconfig_base($conffile);
     # XXX: check if it does actualy need that part
     $config = munin_readconfig_part('datafile', 0);
@@ -208,7 +214,15 @@ Options:
     --help		View this message.
     --debug		View debug messages.
     --stdout		Log to stdout as well as the log file.
-    --force		Send messages even if they shouldn't normally be sent.
+    --always-send <severity list>
+                        Send messages to contacts even if state has
+                        not changed since the last run. The list is a
+                        space or comma separated list of severities.
+                        Choose from one or more of \"critical\",
+                        \"warning\", \"unknown\" and \"ok\".
+    --force		Alias for \"--always-send ok,warning,critical,unknown\".
+                        Overrides --always-send command line, as well as the
+                        always_send contact configuration options.
     --service <service>	Limit notified services to <service>. Multiple 
     			--service options may be supplied.
     --host <host>	Limit notified hosts to <host>. Multiple --host 
@@ -337,7 +351,7 @@ sub process_service {
 		my ($previous_updated_timestamp, $previous_updated_value) = @{ $state->{value}{"$rrd_filename:42"}{previous} || [ ] };
 
 		my $heartbeat = 600; # XXX - $heartbeat is a fixed 10 min (2 runs of 5 min).
-		if (! $field->{type} || $field->{type} eq "GAUGE" || $field->{type} eq "ABSOLUTE") {
+		if (! $field->{type} || $field->{type} eq "GAUGE") {
 			$value = $current_updated_value;
 		} elsif (! defined $current_updated_value || ! defined $previous_updated_value || $current_updated_timestamp == $previous_updated_timestamp) {
 			# No derive computing possible. Report unknown.
@@ -351,10 +365,19 @@ sub process_service {
 		} elsif ($field->{type} eq "COUNTER" && $current_updated_value < $previous_updated_value) {
 			# COUNTER never decrease. Report unknown.
 			$value = "U";
-		} elsif ($current_updated_value eq "U" || $previous_updated_value eq "U" ) {
-			# One of the values is unknown. Report unknown.
+		} elsif ($current_updated_value eq "U") {
+			# The current value is unknown. Report unknown.
+			$value = "U";
+		} elsif ($field->{type} eq "ABSOLUTE") {
+			# The previous value is unimportant, as if ABSOLUTE, the counter is reset anytime the value is read
+			$value = $current_updated_value / ($current_updated_timestamp - $previous_updated_timestamp);
+		} elsif ($previous_updated_value eq "U") {
+			# The previous value is unknown.
+			# Report unknown, as we are not ABSOLUTE
 			$value = "U";
 		} else {
+			# Everything is ok for DERIVE/COUNTER
+			# compute the value per timeunit
 			$value = ($current_updated_value - $previous_updated_value) / ($current_updated_timestamp - $previous_updated_timestamp);
 		}
 	}
@@ -628,8 +651,22 @@ sub generate_service_message {
             next;
         }
         my $obsess = 0;
-	my $always_send = munin_get($contactobj, "always_send");
-	foreach my $cas (split(/\s+/, lc $always_send)) {
+        my $always_send;
+
+        if (@always_send) {
+            # List of severities from command line argument
+            $always_send = \@always_send;
+        }
+        else {
+            # List of severities from contact configuration
+            my $always_send_config = munin_get( $contactobj, "always_send" );
+            my @always_send_config = ($always_send_config);
+            $always_send = \@always_send_config;
+        }
+
+        $always_send = validate_severities($always_send);
+
+        foreach my $cas ( @{$always_send} ) {
 	    if(defined($stats{$cas})) {
 		$obsess += scalar @{$stats{$cas}};
 	    }
@@ -788,4 +825,49 @@ sub message_expand {
     return join('', @res);
 }
 
+=pod
+
+Get a list of severities, and return a sorted, lower cased, unique and
+validated list of severities.
+
+Expects and returns an array reference.
+
+If none of the severities given are on the allowed_severities list, it
+will return a reference to an empty array.
+
+=cut
+
+sub validate_severities {
+    my $severities_ref = shift;
+    my @severities     = @{$severities_ref};
+
+    my @allowed_severities = qw{ok warning critical unknown};
+
+    # Flatten, split on comma and whitespace, and lowercase
+    my @expanded_severities =
+      split( /[[:space:],]+/, lc( join( ',', @severities ) ) );
+
+    # Remove duplicates
+    my %seen;
+    my @unique_severities = grep { !$seen{$_}++ } @expanded_severities;
+
+    # Filter on allowed values
+    my %count;
+    my @validated_severities;
+    foreach my $severity ( @unique_severities, @allowed_severities ) {
+        $count{$severity}++;
+    }
+
+    foreach my $severity ( keys %count ) {
+        if ( $count{$severity} == 2 ) {
+            push @validated_severities, $severity;
+        }
+    }
+
+    # Sort the final list
+    my @sorted_severities = sort(@validated_severities);
+
+    return \@sorted_severities;
+}
+
 1;
